# thmeier-rsync

fork of [puppetlabs-rsync](https://github.com/puppetlabs/puppetlabs-rsync)
with some minor features added

#### Table of Contents

1. [Module Description - What does the module do?](#module-description)
3. [Usage - Configuration options and additional functionality](#usage)
4. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
    * [Classes](#classes)
    * [Defined Types](#defined-types)
5. [Limitations - OS compatibility, etc.](#limitations)

## Module description

puppetlabs-rsync manages rsync clients, repositories, and servers as well as
providing defines to easily grab data via rsync.

## Usage

Install the latest version of rsync
```puppet
class { 'rsync':
  package_ensure => 'latest'
}
```

Get file 'foo' via rsync
```puppet
rsync::get { '/foo':
  source  => "rsync://${rsyncServer}/repo/foo/",
  require => File['/foo'],
}
```

Put file 'foo' on 'rsyncDestHost'
```puppet
rsync::put { '${rsyncDestHost}:/repo/foo':
  user    => 'user',
  source  => "/repo/foo/",
}
```

Setup default rsync repository
```puppet
rsync::server::module{ 'repo':
  path    => $base,
  require => File[$base],
}
```

To disable default values for `incoming_chmod` and `outgoing_chmod`, and
do not add empty values to the resulting config, set both values to `false`

```puppet
rsync::server::module { 'repo':
  path           => $base,
  incoming_chmod => false,
  outgoing_chmod => false,
  require        => File[$base],
}
```

#### Configuring via Hiera
`rsync::put`, `rsync::get`, and `rsync::server::module` resources can be
configured using Hiera hashes. For example:

```yaml
rsync::server::modules:
  myrepo:
    path: /mypath
    incoming_chmod: false
    outgoing_chmod: false
  myotherrepo:
    path: /otherpath
    read_only: false
```

## Reference
See  [REFERENCE.md](REFERENCE.md)
