# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`rsync`](#rsync): install rsync package and create rsync::put/get instances
* [`rsync::server`](#rsync--server): The rsync server. Supports both standard rsync as well as rsync over ssh

### Defined types

* [`rsync::get`](#rsync--get): get files via rsync ussing exec
* [`rsync::put`](#rsync--put): put files via rsync ussing exec
* [`rsync::server::module`](#rsync--server--module): Definition: rsync::server::module  sets up a rsync server

## Classes

### <a name="rsync"></a>`rsync`

install rsync package and create rsync::put/get instances

#### Examples

##### 

```puppet
class { 'rsync':
  package_ensure => 'latest'
}
```

#### Parameters

The following parameters are available in the `rsync` class:

* [`package_ensure`](#-rsync--package_ensure)
* [`manage_package`](#-rsync--manage_package)
* [`puts`](#-rsync--puts)
* [`gets`](#-rsync--gets)

##### <a name="-rsync--package_ensure"></a>`package_ensure`

Data type: `String`

ensure parameter for package-resource

Default value: `'installed'`

##### <a name="-rsync--manage_package"></a>`manage_package`

Data type: `Boolean`

whether to manage the package-resource

Default value: `true`

##### <a name="-rsync--puts"></a>`puts`

Data type: `Hash`

rsync::put instances to create

Default value: `{}`

##### <a name="-rsync--gets"></a>`gets`

Data type: `Hash`

rsync::get instances to create

Default value: `{}`

### <a name="rsync--server"></a>`rsync::server`

The rsync server. Supports both standard rsync as well as rsync over ssh

#### Parameters

The following parameters are available in the `rsync::server` class:

* [`use_xinetd`](#-rsync--server--use_xinetd)
* [`address`](#-rsync--server--address)
* [`use_chroot`](#-rsync--server--use_chroot)
* [`uid`](#-rsync--server--uid)
* [`gid`](#-rsync--server--gid)
* [`port`](#-rsync--server--port)
* [`modules`](#-rsync--server--modules)
* [`syslog_facility`](#-rsync--server--syslog_facility)

##### <a name="-rsync--server--use_xinetd"></a>`use_xinetd`

Data type: `Boolean`

wether to run in xinetd or standaloie

Default value: `true`

##### <a name="-rsync--server--address"></a>`address`

Data type: `String`

adress to listen to

Default value: `'0.0.0.0'`

##### <a name="-rsync--server--use_chroot"></a>`use_chroot`

Data type: `Boolean`

witch for rsync config option "use chrot"

Default value: `true`

##### <a name="-rsync--server--uid"></a>`uid`

Data type: `String`

uid to run the deamon as

Default value: `'nobody'`

##### <a name="-rsync--server--gid"></a>`gid`

Data type: `String`

gid to run the deamon as

Default value: `'nobody'`

##### <a name="-rsync--server--port"></a>`port`

Data type: `String`

tcp port to listen to

Default value: `'873'`

##### <a name="-rsync--server--modules"></a>`modules`

Data type: `Hash`

hash of rsync::server::module resources to create

Default value: `{}`

##### <a name="-rsync--server--syslog_facility"></a>`syslog_facility`

Data type: `String`

syslog facitlity to set for logging

Default value: `'local3'`

## Defined types

### <a name="rsync--get"></a>`rsync::get`

get files via rsync ussing exec

#### Examples

##### 

```puppet
rsync::get { '/foo':
  source  => "rsync://${rsync_server}/repo/foo/",
  require => File['/foo'],
}
```

#### Parameters

The following parameters are available in the `rsync::get` defined type:

* [`source`](#-rsync--get--source)
* [`path`](#-rsync--get--path)
* [`user`](#-rsync--get--user)
* [`keyfile`](#-rsync--get--keyfile)
* [`timeout`](#-rsync--get--timeout)
* [`execuser`](#-rsync--get--execuser)
* [`options`](#-rsync--get--options)
* [`onlyif`](#-rsync--get--onlyif)

##### <a name="-rsync--get--source"></a>`source`

Data type: `String`

source to copy from

##### <a name="-rsync--get--path"></a>`path`

Data type: `String`

path to copy to

Default value: `$name`

##### <a name="-rsync--get--user"></a>`user`

Data type: `Optional[String]`

username on remote system

Default value: `undef`

##### <a name="-rsync--get--keyfile"></a>`keyfile`

Data type: `String`

path to ssh key used to connect to remote host

Default value: `"/home/${user}/.ssh/id_rsa"`

##### <a name="-rsync--get--timeout"></a>`timeout`

Data type: `String`

timeout in seconds

Default value: `'900'`

##### <a name="-rsync--get--execuser"></a>`execuser`

Data type: `String`

user to run the command (passed to exec)

Default value: `'root'`

##### <a name="-rsync--get--options"></a>`options`

Data type: `String`

commandline options to pass to rsync (-a)

Default value: `'-a'`

##### <a name="-rsync--get--onlyif"></a>`onlyif`

Data type: `Optional[String]`

Condition to run the rsync command

Default value: `undef`

### <a name="rsync--put"></a>`rsync::put`

put files via rsync ussing exec

#### Examples

##### 

```puppet
rsync::put { '${rsyncDestHost}:/repo/foo':
  user    => 'user',
  source  => "/repo/foo/",
}
```

#### Parameters

The following parameters are available in the `rsync::put` defined type:

* [`source`](#-rsync--put--source)
* [`path`](#-rsync--put--path)
* [`user`](#-rsync--put--user)
* [`keyfile`](#-rsync--put--keyfile)
* [`timeout`](#-rsync--put--timeout)
* [`options`](#-rsync--put--options)

##### <a name="-rsync--put--source"></a>`source`

Data type: `String`

source to copy from

##### <a name="-rsync--put--path"></a>`path`

Data type: `Optional[String]`

path to copy to

Default value: `undef`

##### <a name="-rsync--put--user"></a>`user`

Data type: `Optional[String]`

username on remote system

Default value: `undef`

##### <a name="-rsync--put--keyfile"></a>`keyfile`

Data type: `String`

path to ssh key used to connect to remote host

Default value: `"/home/${user}/.ssh/id_rsa"`

##### <a name="-rsync--put--timeout"></a>`timeout`

Data type: `String`

timeout in seconds

Default value: `'900'`

##### <a name="-rsync--put--options"></a>`options`

Data type: `String`

commandline options to pass to rsync (-a)

Default value: `'-a'`

### <a name="rsync--server--module"></a>`rsync::server::module`

Definition: rsync::server::module

sets up a rsync server

#### Examples

##### 

```puppet
rsync::server::module { 'repo':
  path    => $base,
  require => File[$base],
}
```

#### Parameters

The following parameters are available in the `rsync::server::module` defined type:

* [`path`](#-rsync--server--module--path)
* [`comment`](#-rsync--server--module--comment)
* [`read_only`](#-rsync--server--module--read_only)
* [`write_only`](#-rsync--server--module--write_only)
* [`use_chroot`](#-rsync--server--module--use_chroot)
* [`list`](#-rsync--server--module--list)
* [`uid`](#-rsync--server--module--uid)
* [`gid`](#-rsync--server--module--gid)
* [`incoming_chmod`](#-rsync--server--module--incoming_chmod)
* [`outgoing_chmod`](#-rsync--server--module--outgoing_chmod)
* [`max_connections`](#-rsync--server--module--max_connections)
* [`lock_file`](#-rsync--server--module--lock_file)
* [`secrets_file`](#-rsync--server--module--secrets_file)
* [`auth_users`](#-rsync--server--module--auth_users)
* [`hosts_allow`](#-rsync--server--module--hosts_allow)
* [`hosts_deny`](#-rsync--server--module--hosts_deny)
* [`transfer_logging`](#-rsync--server--module--transfer_logging)
* [`log_format`](#-rsync--server--module--log_format)
* [`refuse_options`](#-rsync--server--module--refuse_options)
* [`log_file`](#-rsync--server--module--log_file)
* [`dont_compress`](#-rsync--server--module--dont_compress)
* [`order`](#-rsync--server--module--order)
* [`exclude`](#-rsync--server--module--exclude)
* [`pre_xfer_exec`](#-rsync--server--module--pre_xfer_exec)
* [`post_xfer_exec`](#-rsync--server--module--post_xfer_exec)
* [`ignore_nonreadable`](#-rsync--server--module--ignore_nonreadable)
* [`reverse_lookup`](#-rsync--server--module--reverse_lookup)

##### <a name="-rsync--server--module--path"></a>`path`

Data type: `String`

path to data

##### <a name="-rsync--server--module--comment"></a>`comment`

Data type: `Optional[String]`

rsync comment

Default value: `undef`

##### <a name="-rsync--server--module--read_only"></a>`read_only`

Data type: `Boolean`

yes||no, defaults to yes

Default value: `true`

##### <a name="-rsync--server--module--write_only"></a>`write_only`

Data type: `Boolean`

yes||no, defaults to no

Default value: `false`

##### <a name="-rsync--server--module--use_chroot"></a>`use_chroot`

Data type: `Boolean`

yes|no, defaults to undef

Default value: `true`

##### <a name="-rsync--server--module--list"></a>`list`

Data type: `Boolean`

yes||no, defaults to yes

Default value: `true`

##### <a name="-rsync--server--module--uid"></a>`uid`

Data type: `String`

uid of rsync server, defaults to 0

Default value: `'0'`

##### <a name="-rsync--server--module--gid"></a>`gid`

Data type: `String`

gid of rsync server, defaults to 0

Default value: `'0'`

##### <a name="-rsync--server--module--incoming_chmod"></a>`incoming_chmod`

Data type: `Variant[Boolean,String]`

incoming file mode, defaults to 0644

Default value: `'0644'`

##### <a name="-rsync--server--module--outgoing_chmod"></a>`outgoing_chmod`

Data type: `Variant[Boolean,String]`

outgoing file mode, defaults to 0644

Default value: `'0644'`

##### <a name="-rsync--server--module--max_connections"></a>`max_connections`

Data type: `Variant[Integer,String]`

maximum number of simultaneous connections allowed, defaults to 0

Default value: `'0'`

##### <a name="-rsync--server--module--lock_file"></a>`lock_file`

Data type: `String`

file used to support the max connections parameter, defaults to /var/run/rsyncd.lock only needed if max_connections > 0

Default value: `'/var/run/rsyncd.lock'`

##### <a name="-rsync--server--module--secrets_file"></a>`secrets_file`

Data type: `Optional[String]`

path to the file that contains the username:password pairs used for authenticating this module

Default value: `undef`

##### <a name="-rsync--server--module--auth_users"></a>`auth_users`

Data type: `Optional[Array]`

list of usernames that will be allowed to connect to this module

Default value: `undef`

##### <a name="-rsync--server--module--hosts_allow"></a>`hosts_allow`

Data type: `Optional[Array]`

list of patterns allowed to connect to this module (man 5 rsyncd.conf for details)

Default value: `undef`

##### <a name="-rsync--server--module--hosts_deny"></a>`hosts_deny`

Data type: `Optional[Array]`

list of patterns allowed to connect to this module (man 5 rsyncd.conf for details)

Default value: `undef`

##### <a name="-rsync--server--module--transfer_logging"></a>`transfer_logging`

Data type: `Boolean`

parameter enables per-file logging of downloads and uploads in a format
somewhat similar to that used by ftp daemons.

Default value: `false`

##### <a name="-rsync--server--module--log_format"></a>`log_format`

Data type: `Optional[String]`

This parameter allows you to specify the format used for logging file transfers when transfer
logging is enabled. See the rsyncd.conf documentation for more details.

Default value: `undef`

##### <a name="-rsync--server--module--refuse_options"></a>`refuse_options`

Data type: `Optional[Array]`

list of rsync command line options that will be refused by your rsync daemon.

Default value: `undef`

##### <a name="-rsync--server--module--log_file"></a>`log_file`

Data type: `Optional[String]`

log messages to the indicated file rather than using syslog

Default value: `undef`

##### <a name="-rsync--server--module--dont_compress"></a>`dont_compress`

Data type: `Optional[Array[String]]`

wildcard patterns that should not be compressed when pulling files from the daemon

Default value: `undef`

##### <a name="-rsync--server--module--order"></a>`order`

Data type: `String`

concat::fragment order

Default value: `'10'`

##### <a name="-rsync--server--module--exclude"></a>`exclude`

Data type: `Optional[Array]`

space-separated list of daemon exclude patterns.

Default value: `undef`

##### <a name="-rsync--server--module--pre_xfer_exec"></a>`pre_xfer_exec`

Data type: `Optional[String]`

command to be run before and/or after the transfer.

Default value: `undef`

##### <a name="-rsync--server--module--post_xfer_exec"></a>`post_xfer_exec`

Data type: `Optional[String]`

command to be run before and/or after the transfer.

Default value: `undef`

##### <a name="-rsync--server--module--ignore_nonreadable"></a>`ignore_nonreadable`

Data type: `Boolean`



Default value: `false`

##### <a name="-rsync--server--module--reverse_lookup"></a>`reverse_lookup`

Data type: `Boolean`

Controls whether the daemon performs a reverse lookup on the client’s IP address to determine its hostname,
which is used for "hosts allow"/"hosts deny" checks and the "%h" log escape.

Default value: `true`

